<?php
/*
Plugin Name: Woo Admin Notes (EasyToolsWP)
Description: Displays internal notes on the product's frontend only for administrators and adds a field in the product editor to enter the note.
Version: 1.5.1
Author: EasyToolsWP.com
*/

// Ensure the code is not executed directly.
if (!defined('ABSPATH')) {
    exit;
}

// Add a new tab to the product editor.
function wcan_add_custom_product_tabs($tabs) {
    $tabs['admin_notes'] = array(
        'label'    => __('Admin Notes', 'woocommerce'),
        'target'   => 'admin_notes_product_data',
        'class'    => array('show_if_simple', 'show_if_variable'),
        'priority' => 21,
    );
    return $tabs;
}
add_filter('woocommerce_product_data_tabs', 'wcan_add_custom_product_tabs');

// Add fields to the new tab.
function wcan_add_custom_product_fields() {
    ?>
    <div id='admin_notes_product_data' class='panel woocommerce_options_panel'>
        <div class='options_group'>
            <?php
            woocommerce_wp_textarea_input(array(
                'id'          => '_admin_note',
                'label'       => __('Admin Note', 'woocommerce'),
                'description' => __('Add an internal note that will only be visible to administrators on the frontend.', 'woocommerce'),
                'desc_tip'    => true,
            ));
            woocommerce_wp_select(array(
                'id'          => '_admin_note_position',
                'label'       => __('Note Position', 'woocommerce'),
                'options'     => array(
                    'top'        => __('Top', 'woocommerce'),
                    'bottom'     => __('Bottom', 'woocommerce'),
                    'top_bottom' => __('Top & Bottom', 'woocommerce'),
                ),
                'description' => __('Choose where the note should appear on the frontend.', 'woocommerce'),
                'desc_tip'    => true,
            ));
            ?>
        </div>
    </div>
    <?php
}
add_action('woocommerce_product_data_panels', 'wcan_add_custom_product_fields');

// Save the field value.
function wcan_save_custom_product_fields($post_id) {
    $admin_note = isset($_POST['_admin_note']) ? sanitize_textarea_field($_POST['_admin_note']) : '';
    $note_position = isset($_POST['_admin_note_position']) ? sanitize_text_field($_POST['_admin_note_position']) : 'bottom';
    update_post_meta($post_id, '_admin_note', $admin_note);
    update_post_meta($post_id, '_admin_note_position', $note_position);
}
add_action('woocommerce_process_product_meta', 'wcan_save_custom_product_fields');

// Display the internal note on the frontend based on the selected position.
function wcan_display_admin_note_top() {
    if (current_user_can('administrator')) {
        global $post;
        $admin_note = get_post_meta($post->ID, '_admin_note', true);
        $note_position = get_post_meta($post->ID, '_admin_note_position', true);

        if (!empty($admin_note) && ($note_position === 'top' || $note_position === 'top_bottom')) {
            echo '<div class="woocommerce-admin-note top">';
            echo '<h3>' . __('Admin Note', 'woocommerce') . '</h3>';
            echo '<p>' . esc_html($admin_note) . '</p>';
            echo '</div>';
        }
    }
}

function wcan_display_admin_note_bottom() {
    if (current_user_can('administrator')) {
        global $post;
        $admin_note = get_post_meta($post->ID, '_admin_note', true);
        $note_position = get_post_meta($post->ID, '_admin_note_position', true);

        if (!empty($admin_note) && ($note_position === 'bottom' || $note_position === 'top_bottom')) {
            echo '<div class="woocommerce-admin-note bottom">';
            echo '<h3>' . __('Admin Note', 'woocommerce') . '</h3>';
            echo '<p>' . esc_html($admin_note) . '</p>';
            echo '</div>';
        }
    }
}

// Add the internal note to the frontend based on the position.
function wcan_add_admin_note_to_product() {
    if (current_user_can('administrator')) {
        add_action('woocommerce_before_single_product_summary', 'wcan_display_admin_note_top', 5);
        add_action('woocommerce_after_single_product_summary', 'wcan_display_admin_note_bottom', 20);
    }
}
add_action('wp', 'wcan_add_admin_note_to_product');

// Add inline CSS.
function wcan_admin_note_css() {
    echo "
    <style>
        .woocommerce-admin-note.top {
            margin: 20px; /* Adjust this value as needed */
            background: #f9f9f9;
            border: 1px solid #ddd;
            padding: 10px;
        }

        .woocommerce-admin-note.bottom {
            margin: 20px; /* Adjust this value as needed */
            background: #f9f9f9;
            border: 1px solid #ddd;
            padding: 10px;
        }
    </style>
    ";
}
add_action('wp_head', 'wcan_admin_note_css');
